from setuptools import setup, find_packages


setup(name="django-smart-selects",
      version="1.2.9",
      description="Django application to handle chained model fields.",
      author="Patrick Lauber",
      author_email="digi@treepy.com",
      url="https://github.com/digi604/django-smart-selects",
      packages=find_packages(),
      include_package_data=True,
      )
